@@ -8,13 +8,24 @@ from seesaw.event import Event
 
 
 class Pipeline(object):
+    '''The sequence of steps that complete a :class:`Task`.
+
+    Your pipeline will probably be something like this:
+
+    1. Request an assignment from the tracker.
+    2. Run Wget to download the file.
+    3. Upload the downloaded file with rsync.
+    4. Tell the tracker that the assignment is done.
+    '''
     def __init__(self, *tasks):
         self.cwd = os.getcwd()
+        self.data_dir = os.path.join(self.cwd, "data")
         self.on_start_item = Event()
         self.on_complete_item = Event()
         self.on_fail_item = Event()
         self.on_cancel_item = Event()
         self.on_finish_item = Event()
+        self.project = None
 
         self.items_in_pipeline = set()
         self.tasks = []
